==> microprofile-fault-tolerance-tck-3.0-sources.jar: org/eclipse/microprofile/fault/tolerance/tck/bulkhead/clientserver/Bulkhead1Retry1SyncMethodBean.java <==
/*
 *******************************************************************************
 * Copyright (c) 2018-2020 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/
package org.eclipse.microprofile.fault.tolerance.tck.bulkhead.clientserver;

import javax.enterprise.context.ApplicationScoped;

import org.eclipse.microprofile.fault.tolerance.tck.util.Barrier;
import org.eclipse.microprofile.fault.tolerance.tck.util.TestException;
import org.eclipse.microprofile.faulttolerance.Bulkhead;
import org.eclipse.microprofile.faulttolerance.Retry;

/**
 * Test to ensure that the bulkhead slot is released when retrying.
 * <p>
 * Has a bulkhead of size 1
 * <p>
 * Retries 1 time on thrown TestException with 1 second delay
 */
@ApplicationScoped
public class Bulkhead1Retry1SyncMethodBean {
    
    @Retry(maxRetries = 1, delay = 1000, jitter = 0, retryOn = TestException.class)
    @Bulkhead(1)
    public void test(Barrier barrier, RuntimeException ex) {
        barrier.await();
        if (ex != null) {
            throw ex;
        }
    }

}

==> microprofile-fault-tolerance-tck-4.0-sources.jar: org/eclipse/microprofile/fault/tolerance/tck/bulkhead/clientserver/Bulkhead1Retry1SyncMethodBean.java <==
/*
 *******************************************************************************
 * Copyright (c) 2018-2020 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/
package org.eclipse.microprofile.fault.tolerance.tck.bulkhead.clientserver;

import org.eclipse.microprofile.fault.tolerance.tck.util.Barrier;
import org.eclipse.microprofile.fault.tolerance.tck.util.TestException;
import org.eclipse.microprofile.faulttolerance.Bulkhead;
import org.eclipse.microprofile.faulttolerance.Retry;

import jakarta.enterprise.context.ApplicationScoped;

/**
 * Test to ensure that the bulkhead slot is released when retrying.
 * <p>
 * Has a bulkhead of size 1
 * <p>
 * Retries 1 time on thrown TestException with 1 second delay
 */
@ApplicationScoped
public class Bulkhead1Retry1SyncMethodBean {

    @Retry(maxRetries = 1, delay = 1000, jitter = 0, retryOn = TestException.class)
    @Bulkhead(1)
    public void test(Barrier barrier, RuntimeException ex) {
        barrier.await();
        if (ex != null) {
            throw ex;
        }
    }

}
